@@ -15,12 +15,13 @@
 #'
 #'
 #' @examples
-#' \dontrun{
 #' 
+#' \donttest{
 #' # Local spatio-temporal Poisson process model
 #' 
+#' set.seed(2)
 #' inh <- rstpp(lambda = function(x, y, t, a) {exp(a[1] + a[2]*x)}, 
-#'              par = c(0.005, 5), seed = 2)
+#'              par = c(0.005, 5))
 #' inh_local <- locstppm(inh, formula = ~ x)
 #' 
 #' localplot(inh_local)
@@ -32,7 +33,6 @@
 #'
 #' localplot(lgcp_loc)
 #' 
-#'
 #'}
 #'
 #'
@@ -43,7 +43,6 @@
 #'
 #'
 localplot <- function(x, par = TRUE){
-  if (!inherits(x, c("stlgcppm", "locstppm"))) stop("x should be either from class stlgcppm or locstppm")
   UseMethod("localplot")
 }
 
