@@ -13,7 +13,6 @@
 #'
 #' @examples
 #'
-#' \dontrun{
 #' set.seed(2)
 #' df <- data.frame(cbind(runif(100), runif(100), runif(100), rpois(100, 15),
 #' rpois(100, 30)))
@@ -21,13 +20,11 @@
 #' stpm1 <- stpm(df)
 #'
 #' summary(stpm1)
-#' }
 #'
 #'
 print.stpm <- function (x, ...) 
 {
-  if (!inherits(x, c("stpm"))) stop("X should be from class stpm")
-  
+
   cat("Spatio-temporal marked point pattern \n")
   {
     cat(paste0(nrow(x$df), " ", "points"), "\n")
