@@ -26,8 +26,6 @@
 #'
 #' @examples
 #'
-#' \dontrun{
-#'
 #' set.seed(2)
 #' df <- data.frame(runif(100), runif(100), runif(100))
 #' 
@@ -38,18 +36,23 @@
 #' 
 #' stlp1 <- stp(df_net, L = chicagonet)
 #'
-#' }
-#'
 #'
 stp <- function(df, L){
   
+  if (!inherits(df, c("matrix", "data.frame"))){
+    stop("df should be either a matrix or a data.frame")
+  } 
+  
   colnames(df) <- c("x", "y", "t")
-  df <- data.frame(df)
+  if (!inherits(df, c("data.frame"))) df <- data.frame(df)
   
   if(missing(L)){
     out <- list(df = df)
     class(out) <- "stp"
   } else {
+    if (!inherits(L, c("linnet"))){
+      stop("L should be a linnet object")
+    } 
     suppressWarnings(lpp_new <- spatstat.linnet::lpp(df, L))
     df_new <- data.frame(x = lpp_new$data[, 1], y = lpp_new$data[, 2 ], t = df[, 3])
     out <- list(df = df_new, L = L)
