@@ -16,14 +16,12 @@
 #'
 #'
 #' @examples
-#' \dontrun{
 #'
-#' pin <- rstpp(lambda = function(x, y, t, a) {exp(a[1] + a[2]*x)}, par = c(2, 6),
-#'              seed = 2)
+#' set.seed(2)
+#' pin <- rstpp(lambda = function(x, y, t, a) {exp(a[1] + a[2]*x)}, par = c(2, 6))
 #' inh1 <- stppm(pin, formula = ~ x)
 #' 
 #' summary(inh1)
-#'}
 #'
 #'
 #' @references
@@ -32,8 +30,7 @@
 #'
 #'
 summary.stppm <- function(object, ...){
-  if(!inherits(object, "stppm")) stop("class(object) must be stppm")
-  
+
   if(length(object$IntCoefs) == 1){
     cat("Homogeneous Poisson process \n")
     cat("with Intensity: ")
